==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/lv/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Lietotājs vietnē ir atcēlis objekta pieprasījumu',
    'a_user_requested' => 'Lietotājs ir pieprasījis vienumu vietnē',
    'accessory_name' => 'Piederumu nosaukums:',
    'additional_notes' => 'Papildu piezīmes:',
    'admin_has_created' => 'Administrators ir izveidojis jums kontu: tīmekļa vietnē.',
    'asset' => 'Aktīvs:',
    'asset_name' => 'Aktīvu nosaukums:',
    'asset_requested' => 'Aktīvs pieprasīts',
    'asset_tag' => 'Aktīvu tags:',
    'assigned_to' => 'Piešķirts',
    'best_regards' => 'Ar laba vēlējumiem,',
    'canceled' => 'Atcelts:',
    'checkin_date' => 'Reģistrēšanās datums:',
    'checkout_date' => 'Izrakstīšanās datums:',
    'click_to_confirm' => 'Lūdzu, noklikšķiniet uz šīs saites, lai apstiprinātu savu: tīmekļa kontu:',
    'click_on_the_link_accessory' => 'Lūdzu, noklikšķiniet uz saites apakšā, lai apstiprinātu, ka esat saņēmis piederumu.',
    'click_on_the_link_asset' => 'Lūdzu, noklikšķiniet uz saites apakšā, lai apstiprinātu, ka esat saņēmis šo īpašumu.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Pašreizējais QTY',
    'Days' => 'Dienas',
    'days' => 'Dienas',
    'expecting_checkin_date' => 'Paredzamais reģistrēšanās datums:',
    'expires' => 'Beidzas',
    'Expiring_Assets_Report' => 'Pabeidzis aktīvu pārskats.',
    'Expiring_Licenses_Report' => 'Pabeidzamo licenču pārskats.',
    'hello' => 'Sveiki',
    'hi' => 'Sveiki',
    'i_have_read' => 'Esmu izlasījis un piekrītu lietošanas noteikumiem un saņēmu šo preci.',
    'item' => 'Vienība:',
    'Item_Request_Canceled' => 'Vienuma pieprasījums atcelts',
    'Item_Requested' => 'Pieprasīts vienums',
    'link_to_update_password' => 'Lūdzu, noklikšķiniet uz šīs saites, lai atjauninātu savu: web paroli:',
    'login_first_admin' => 'Piesakieties savā jaunajā Snipe-IT instalācijā, izmantojot tālāk minētos akreditācijas datus.',
    'login' => 'Pieslēgties:',
    'Low_Inventory_Report' => 'Zema inventarizācijas atskaite',
    'min_QTY' => 'Min QTY',
    'name' => 'Nosaukums',
    'new_item_checked' => 'Jauns objekts ir atzīmēts zem sava vārda, sīkāk ir sniegta zemāk.',
    'password' => 'Parole:',
    'password_reset' => 'Paroles atiestatīšana',

    'read_the_terms' => 'Lūdzu, izlasiet lietošanas noteikumus zemāk.',
    'read_the_terms_and_click' => 'Lūdzu, izlasiet lietošanas noteikumus zemāk un noklikšķiniet uz saites apakšā, lai apstiprinātu, ka esat izlasījis un piekrītu lietošanas noteikumiem, un esat saņēmis šo īpašumu.',
    'requested' => 'Pieprasīts:',
    'reset_link' => 'Jūsu paroles atiestatīšanas saite',
    'reset_password' => 'Noklikšķiniet šeit, lai atiestatītu savu paroli:',
    'serial' => 'Sērijas numurs',
    'supplier' => 'Piegādātājs',
    'tag' => 'Tag',
    'test_email' => 'Pārbaudiet e-pastu no Snipe-IT',
    'test_mail_text' => 'Šis ir tests no Snipe-IT Asset Management System. Ja jums ir šis, pasts darbojas :)',
    'the_following_item' => 'Šis ieraksts ir atzīmēts:',
    'low_inventory_alert' => ':count vienības skaits ir zemāks par krājuma minimumu vai drīz būs zems.|:count vienību skaits ir zemāks par krājuma minimumu vai drīz būs zems.',
    'assets_warrantee_alert' => ':count aktīvam beigsies garantijas termiņš pēc :threshold dienām.|:count aktīviem beigsies garantijas termiņš pēc :threshold dienām.',
    'license_expiring_alert' => 'Pēc :threshold dienām beigsies termiņš :count licencei.| Pēc :threshold dienām beigsies termiņš :threshold :count licencēm.',
    'to_reset' => 'Lai atiestatītu: tīmekļa paroli, aizpildiet šo veidlapu:',
    'type' => 'Tips',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Lietotājs',
    'username' => 'Lietotājvārds',
    'welcome' => 'Sveicināti: vārds',
    'welcome_to' => 'Laipni lūdzam: tīmeklī!',
    'your_credentials' => 'Jūsu Snipe-IT akreditācijas dati',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/lv/mail.php <==
<?php

return [
    'a_user_canceled' => 'Lietotājs vietnē ir atcēlis objekta pieprasījumu',
    'a_user_requested' => 'Lietotājs ir pieprasījis vienumu vietnē',
    'accessory_name' => 'Piederumu nosaukums:',
    'additional_notes' => 'Papildu piezīmes:',
    'admin_has_created' => 'Administrators ir izveidojis jums kontu: tīmekļa vietnē.',
    'asset' => 'Aktīvs:',
    'asset_name' => 'Aktīvu nosaukums:',
    'asset_requested' => 'Aktīvs pieprasīts',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'Piešķirts',
    'best_regards' => 'Ar laba vēlējumiem,',
    'canceled' => 'Atcelts:',
    'checkin_date' => 'Reģistrēšanās datums:',
    'checkout_date' => 'Izrakstīšanās datums:',
    'click_to_confirm' => 'Lūdzu, noklikšķiniet uz šīs saites, lai apstiprinātu savu: tīmekļa kontu:',
    'click_on_the_link_accessory' => 'Lūdzu, noklikšķiniet uz saites apakšā, lai apstiprinātu, ka esat saņēmis piederumu.',
    'click_on_the_link_asset' => 'Lūdzu, noklikšķiniet uz saites apakšā, lai apstiprinātu, ka esat saņēmis šo īpašumu.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Pašreizējais QTY',
    'Days' => 'Dienas',
    'days' => 'Dienas',
    'expecting_checkin_date' => 'Paredzamais reģistrēšanās datums:',
    'expires' => 'Beidzas',
    'Expiring_Assets_Report' => 'Pabeidzis aktīvu pārskats.',
    'Expiring_Licenses_Report' => 'Pabeidzamo licenču pārskats.',
    'hello' => 'Sveiki',
    'hi' => 'Sveiki',
    'i_have_read' => 'Esmu izlasījis un piekrītu lietošanas noteikumiem un saņēmu šo preci.',
    'item' => 'Vienība:',
    'Item_Request_Canceled' => 'Vienuma pieprasījums atcelts',
    'Item_Requested' => 'Pieprasīts vienums',
    'link_to_update_password' => 'Lūdzu, noklikšķiniet uz šīs saites, lai atjauninātu savu: web paroli:',
    'login_first_admin' => 'Piesakieties savā jaunajā Snipe-IT instalācijā, izmantojot tālāk minētos akreditācijas datus.',
    'login' => 'Pieslēgties:',
    'Low_Inventory_Report' => 'Zema inventarizācijas atskaite',
    'min_QTY' => 'Min QTY',
    'name' => 'Nosaukums',
    'new_item_checked' => 'Jauns objekts ir atzīmēts zem sava vārda, sīkāk ir sniegta zemāk.',
    'password' => 'Parole:',
    'password_reset' => 'Paroles atiestatīšana',

    'read_the_terms' => 'Lūdzu, izlasiet lietošanas noteikumus zemāk.',
    'read_the_terms_and_click' => 'Lūdzu, izlasiet lietošanas noteikumus zemāk un noklikšķiniet uz saites apakšā, lai apstiprinātu, ka esat izlasījis un piekrītu lietošanas noteikumiem, un esat saņēmis šo īpašumu.',
    'requested' => 'Pieprasīts:',
    'reset_link' => 'Jūsu paroles atiestatīšanas saite',
    'reset_password' => 'Noklikšķiniet šeit, lai atiestatītu savu paroli:',
    'serial' => 'Sērijas numurs',
    'supplier' => 'Piegādātājs',
    'tag' => 'Tag',
    'test_email' => 'Pārbaudiet e-pastu no Snipe-IT',
    'test_mail_text' => 'Šis ir tests no Snipe-IT Asset Management System. Ja jums ir šis, pasts darbojas :)',
    'the_following_item' => 'Šis ieraksts ir atzīmēts:',
    'low_inventory_alert' => ':count vienības skaits ir zemāks par krājuma minimumu vai drīz būs zems.|:count vienību skaits ir zemāks par krājuma minimumu vai drīz būs zems.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'Pēc :threshold dienām beigsies termiņš :count licencei.| Pēc :threshold dienām beigsies termiņš :threshold :count licencēm.',
    'to_reset' => 'Lai atiestatītu: tīmekļa paroli, aizpildiet šo veidlapu:',
    'type' => 'Tips',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Lietotājs',
    'username' => 'Lietotājvārds',
    'welcome' => 'Sveicināti: vārds',
    'welcome_to' => 'Laipni lūdzam: tīmeklī!',
    'your_credentials' => 'Jūsu Snipe-IT akreditācijas dati',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
];
